@@ -23,8 +23,8 @@ else:
 __all__ = (
     "ResponseMetadataTypeDef",
     "SendSSHPublicKeyRequestRequestTypeDef",
-    "SendSSHPublicKeyResponseTypeDef",
     "SendSerialConsoleSSHPublicKeyRequestRequestTypeDef",
+    "SendSSHPublicKeyResponseTypeDef",
     "SendSerialConsoleSSHPublicKeyResponseTypeDef",
 )
 
@@ -62,15 +62,6 @@ class SendSSHPublicKeyRequestRequestTypeDef(
     pass
 
 
-SendSSHPublicKeyResponseTypeDef = TypedDict(
-    "SendSSHPublicKeyResponseTypeDef",
-    {
-        "RequestId": str,
-        "Success": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredSendSerialConsoleSSHPublicKeyRequestRequestTypeDef = TypedDict(
     "_RequiredSendSerialConsoleSSHPublicKeyRequestRequestTypeDef",
     {
@@ -94,11 +85,20 @@ class SendSerialConsoleSSHPublicKeyRequestRequestTypeDef(
     pass
 
 
+SendSSHPublicKeyResponseTypeDef = TypedDict(
+    "SendSSHPublicKeyResponseTypeDef",
+    {
+        "RequestId": str,
+        "Success": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 SendSerialConsoleSSHPublicKeyResponseTypeDef = TypedDict(
     "SendSerialConsoleSSHPublicKeyResponseTypeDef",
     {
         "RequestId": str,
         "Success": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
